from datetime import datetime, timedelta

from django import template
from django.utils.html import format_html

from billard import utils

register = template.Library()


@register.filter(is_safe=True)
def display_client(client, desk_no):
    desks = client.desks.filter(desk_no=desk_no)
    if len(desks) == 0:
        return ''
    desk = desks[0]
    loc = desk.client.location
    if not desk.enabled:
        return ''
    alert = 'alert-success'
    acc = desk.accounting_set.all()[:3][::-1]
    if acc is not None and len(acc) > 0:
        a = acc[-1]
        if a.time_to is None:
            alert = 'alert-info'
            prize, u1, u2 = utils.get_prize_for(
                start=a.time_from,
                end=datetime.now(),
                pph=desk.prize,
                hh_start=loc.happy_hour_start,
                hh_end=loc.happy_hour_end,
                pphh=desk.prize_hh,
            )
            prize = '{0:.2f}'.format(prize)
            if prize != a.prize:
                a.prize = prize
    before5min = datetime.now() - timedelta(minutes=5)
    if client.last_seen is not None and client.last_seen < before5min:
        alert = 'alert-danger'
    html = '<div class="col col-12 col-lg-6">\n'
    html += '    <div class="table-info alert {}">\n'.format(alert)
    html += '        <h4 style="text-align: center">({}) {}</h4>\n'.format(desk_no, desk.name)
    if loc.happy_hour_start is not None and desk.prize_hh is not None:
        html += '        <h6 style="text-align: center">Preis: {:.2f} € / Stunde | {} - {}: {:.2f} / € Stunde</h6>\n' \
            .format(
            desk.prize,
            loc.happy_hour_start.strftime('%H:%M'),
            loc.happy_hour_end.strftime('%H:%M'),
            desk.prize_hh, )
    else:
        html += '        <h6 style="text-align: center">Preis: {0:.2f} / Stunde</h6>\n'.format(
            desk.prize, )
    if len(acc) > 0:
        html += '        <table class="table">\n'
        for a in acc:
            html += '            <tr>\n'
            html += '                <td>{}</td>\n'.format(a.time_from.strftime('%d.%m.%Y %H:%M:%S'))
            html += '                <td>{}</td>\n'.format(
                (a.time_to.strftime('%d.%m.%Y %H:%M:%S') if a.time_to is not None else ''))
            html += '                <td style="text-align: center;">{}</td>\n' \
                .format((a.prize if a.prize is not None else ''))
            html += '            <tr>\n'
            html += '            <tr>\n'
            html += '            </tr>\n'
        html += '        </table>\n'
    html += '    </div>\n'
    html += '</div>\n'
    html = format_html(html)
    return html
